@@ -34,7 +34,10 @@ def censor_file(file, run_files=True, run_out_dirs=None, cut_files=True,
                 strict=True,
                 references=None,
                 license_head=None):
+    if str(file).endswith("rst"):
+        assert not run_files and not cut_files and not censor_files
 
+        print(file)
     if references == None:
         references = {}
 
@@ -50,7 +53,10 @@ def censor_file(file, run_files=True, run_out_dirs=None, cut_files=True,
             lines[k] = l.replace("# !", "#!")
 
         try:
-            lines = fix_citations(lines, references, strict=strict)
+            # if str(file).endswith("rst"):
+            #     print(file)
+            lines = fix_citations(lines, references, strict=strict, file=file)
+
         except IndexError as e:
             print(e)
             print("Error in file, cite/reference tag not found!>", file)
